==> elgg-1.12.12.zip: elgg-1.12.12/mod/groups/languages/fi.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Ryhmät",
	'groups:owned' => "Ryhmät, jotka omistan",
	'groups:owned:user' => 'Käyttäjän %s omistamat ryhmät',
	'groups:yours' => "Omat ryhmäni",
	'groups:user' => "Käyttäjän %s ryhmät",
	'groups:all' => "Kaikki ryhmät",
	'groups:add' => "Luo uusi ryhmä",
	'groups:edit' => "Muokkaa ryhmää",
	'groups:delete' => 'Poista ryhmä',
	'groups:membershiprequests' => 'Hallinnoi liittymispyyntöjä',
	'groups:membershiprequests:pending' => 'Hallinnoi liittymispyyntöjä (%s)',
	'groups:invitations' => 'Ryhmäkutsut',
	'groups:invitations:pending' => 'Ryhmäkutsut (%s)',

	'groups:icon' => 'Ryhmän kuvake (jätä tyhjäksi, jos et halua vaihtaa)',
	'groups:name' => 'Ryhmän nimi',
	'groups:username' => 'Ryhmän lyhyt nimi (näytetään osoitteissa, käytä vain kirjaimia ja numeroita)',
	'groups:description' => 'Kuvaus',
	'groups:briefdescription' => 'Lyhyt kuvaus',
	'groups:interests' => 'Tagit',
	'groups:website' => 'Nettisivu',
	'groups:members' => 'Ryhmän jäsenet',
	'groups:my_status' => 'Oma jäsenyytesi',
	'groups:my_status:group_owner' => 'Olet ryhmän omistaja',
	'groups:my_status:group_member' => 'Olet ryhmän jäsen',
	'groups:subscribed' => 'Olet tilannut ryhmän ilmoitukset',
	'groups:unsubscribed' => 'Et ole tilannut ryhmän ilmoituksia',

	'groups:members:title' => 'Jäsenet ryhmässä: %s',
	'groups:members:more' => "Näytä kaikki jäsenet",
	'groups:membership' => "Ryhmän jäsenyysasetukset",
	'groups:content_access_mode' => "Pääsy ryhmän sisältöihin",
	'groups:content_access_mode:warning' => "Varoitus: Asetuksen muuttaminen vaikuttaa vain uusiin sisältöihin.",
	'groups:content_access_mode:unrestricted' => "Rajoittamaton - Näkyvyys riippuu kunkin sisällön omasta näkyvyystasosta",
	'groups:content_access_mode:membersonly' => "Vain jäsenet - Ryhmän ulkopuoliset eivät pääse ollenkaan käsiksi sisältöihin",
	'groups:access' => "Pääsyoikeudet",
	'groups:owner' => "Omistaja",
	'groups:owner:warning' => "Varoitus: Jos muutat tätä, luovut ryhmän omistajuudesta.",
	'groups:widget:num_display' => 'Näytettävien ryhmien määrä',
	'groups:widget:membership' => 'Ryhmien jäsenyys',
	'groups:widgets:description' => 'Näytä profiilissasi ryhmät, joiden jäsenenä olet',

	'groups:widget:group_activity:title' => 'Ryhmän toiminta',
	'groups:widget:group_activity:description' => 'Näyttää valitsemasi ryhmän toiminta',
	'groups:widget:group_activity:edit:select' => 'Valitse',
	'groups:widget:group_activity:content:noactivity' => 'Ryhmässä ei ole vielä ollut toimintaa',
	'groups:widget:group_activity:content:noselect' => 'Valitse ryhmä vimpaimen asetuksista',

	'groups:noaccess' => 'Sinulla ei ole oikeuksia tämän ryhmän näkemiseen',
	'groups:permissions:error' => 'Sinulla ei ole oikeuksia tähän',
	'groups:ingroup' => 'ryhmässä',
	'groups:cantcreate' => 'Vain sivuston ylläpitäjät voivat luoda uusia ryhmiä.',
	'groups:cantedit' => 'Voit nyt muokata ryhmää',
	'groups:saved' => 'Ryhmä tallennettu',
	'groups:save_error' => 'Ryhmän tallentaminen epäonnistui',
	'groups:featured' => 'Valikoidut ryhmät',
	'groups:makeunfeatured' => 'Poista mainos',
	'groups:makefeatured' => 'Mainosta ryhmää',
	'groups:featuredon' => '%s on nyt mainostettu ryhmä.',
	'groups:unfeatured' => '%s on poistettu mainostettavista ryhmistä.',
	'groups:featured_error' => 'Virheellinen ryhmä.',
	'groups:nofeatured' => 'Ei valikoituja ryhmiä',
	'groups:joinrequest' => 'Ano jäsenyyttä',
	'groups:join' => 'Liity ryhmään',
	'groups:leave' => 'Eroa ryhmästä',
	'groups:invite' => 'Kutsu ystäviä',
	'groups:invite:title' => 'Kutsu ystäviä ryhmään',
	'groups:inviteto' => "Kutsu ystäviä ryhmään '%s'",
	'groups:nofriends' => "Kaikki ystäväsi on jo kutsuttu ryhmän jäseniksi.",
	'groups:nofriendsatall' => 'Sinulla ei vielä ole ystäviä, joita kutsua!',
	'groups:viagroups' => "lisäsi uuden viestin keskusteluun",
	'groups:group' => "Ryhmä",
	'groups:search:tags' => "tagi",
	'groups:search:title' => "Ryhmät, joissa tagi '%s'",
	'groups:search:none' => "Ryhmiä ei löytynyt",
	'groups:search_in_group' => "Etsi tästä ryhmästä",
	'groups:acl' => "Ryhmä: %s",

	'discussion:topic:notify:summary' => 'Uusi keskustelu: %s',
	'discussion:topic:notify:subject' => 'Uusi keskustelu: %s',
	'discussion:topic:notify:body' =>
'%s lisäsi uuden keskustelun ryhmään %s:

Aihe: %s

%s

Voit osallistua keskusteluun osoitteessa:
%s
',

	'discussion:reply:notify:summary' => 'Uusi viesti keskustelussa: %s',
	'discussion:reply:notify:subject' => 'Uusi viesti keskustelussa: %s',
	'discussion:reply:notify:body' =>
'%s vastasi keskusteluun  %s ryhmässä %s:

%s

Osallistu keskusteluun:
%s
',

	'groups:activity' => "Ryhmän toiminta",
	'groups:enableactivity' => 'Ota käyttöön ryhmän toiminta',
	'groups:activity:none' => "Ryhmässä ei vielä ole ollut toimintaa",

	'groups:notfound' => "Ryhmää ei löytynyt",
	'groups:notfound:details' => "Pyydettyä ryhmää ei joko ole olemassa tai sinulla ei ole oikeuksia siihen",

	'groups:requests:none' => 'Ei odottavia jäsenyyspyyntöjä.',

	'groups:invitations:none' => 'Ei odottavia kutsuja.',

	'item:object:groupforumtopic' => "Keskusteluaiheet",
	'item:object:discussion_reply' => "Vastaukset keskusteluihin",

	'groupforumtopic:new' => "Uusi viesti keskustelussa",

	'groups:count' => "ryhmää luotuna",
	'groups:open' => "avoin ryhmä",
	'groups:closed' => "suljettu ryhmä",
	'groups:member' => "jäsentä",
	'groups:searchtag' => "Etsi ryhmiä tagin perusteella",

	'groups:more' => 'Lisää ryhmiä',
	'groups:none' => 'Ei ryhmiä',

	/**
	 * Access
	 */
	'groups:access:private' => 'Suljettu - Jäsenet pitää kutsua',
	'groups:access:public' => 'Avoin - Kuka tahansa voi liittyä',
	'groups:access:group' => 'Vain ryhmän jäsenet',
	'groups:closedgroup' => "Tällä ryhmällä on suljettu jäsenyys.",
	'groups:closedgroup:request' => 'Klikkaa linkkiä "Ano jäsenyyttä" päästäksesi jäseneksi.',
	'groups:closedgroup:membersonly' => "Tällä ryhmällä on suljettu jäsenyys, ja vain jäsenet pääsevät käsiksi sen sisältöihin.",
	'groups:opengroup:membersonly' => "Vain jäsenillä on pääsy tämän ryhmän sisältöihin.",
	'groups:opengroup:membersonly:join' => 'Klikkaa "Liity ryhmään" päästäksesi ryhmän jäseneksi.',
	'groups:visibility' => 'Kuka voi nähdä tämän ryhmän?',

	/**
	 * Group tools
	 */
	'groups:enableforum' => 'Ota käyttöön ryhmän keskustelut',
	'groups:lastupdated' => 'Viimeksi päivitetty %s käyttäjän %s toimesta',
	'groups:lastcomment' => 'Viimeksi kommentoitu %s käyttäjän %s toimesta',

	/**
	 * Group discussion
	 */
	'discussion' => 'Keskustelut',
	'discussion:add' => 'Lisää uusi keskustelu',
	'discussion:latest' => 'Viimeisimmät keskustelut',
	'discussion:group' => 'Ryhmän keskustelut',
	'discussion:none' => 'Keskusteluja ei ole vielä luotu',
	'discussion:reply:title' => 'Vastaus käyttäjältä %s',

	'discussion:topic:created' => 'Luotiin uusi keskusteluaihe.',
	'discussion:topic:updated' => 'Keskusteluaihe päivitetty.',
	'discussion:topic:deleted' => 'Keskusteluaihe poistettu.',

	'discussion:topic:notfound' => 'Keskustelua ei löytynyt',
	'discussion:error:notsaved' => 'Keskustelun tallentaminen epäonnistui',
	'discussion:error:missing' => 'Sekä otsikko että viesti ovat pakollisia tietoja',
	'discussion:error:permissions' => 'Sinulla ei ole oikeuksia tämän toiminnon suorittamiseen',
	'discussion:error:notdeleted' => 'Keskustelun poistaminen epäonnistui',

	'discussion:reply:edit' => 'Muokkaa',
	'discussion:reply:deleted' => 'Vastaus poistettu.',
	'discussion:reply:error:notfound' => 'Viestiä ei löytynt',
	'discussion:reply:error:notfound_fallback' => "Etsimääsi viestiä ei löytynyt, mutta ohjasimme sinut viestiketjuun, jonne se oli jätetty.",
	'discussion:reply:error:notdeleted' => 'Viestiä ei voitu poistaa',

	'discussion:search:title' => 'Vastaus aiheeseen: %s',
	
	'admin:groups' => 'Ryhmät',

	'reply:this' => 'Vastaa',

	'group:replies' => 'Vastaukset',
	'groups:forum:created' => 'Created %s with %d comments',
	'groups:forum:created:single' => 'Created %s with %d reply',
	'groups:forum' => 'Keskustelu',
	'groups:addtopic' => 'Lisää keskustelu',
	'groups:forumlatest' => 'Viimeisin keskustelu',
	'groups:latestdiscussion' => 'Viimeisin keskustelu',
	'groupspost:success' => 'Vastauksesi tallennettiin',
	'groupspost:failure' => 'Vastauksen tallentaminen epäonnistui',
	'groups:alldiscussion' => 'Viimeisimmät keskustelut',
	'groups:edittopic' => 'Muokkaa keskustelun aihetta',
	'groups:topicmessage' => 'Viesti',
	'groups:topicstatus' => 'Aiheen tila',
	'groups:reply' => 'Lisää kommentti',
	'groups:topic' => 'Aihe',
	'groups:posts' => 'Viestit',
	'groups:lastperson' => 'Viimeisin henkilö',
	'groups:when' => 'Milloin',
	'grouptopic:notcreated' => 'Keskusteluja ei vielä ole luotu.',
	'groups:topicclosed' => 'Suljettu',
	'grouptopic:created' => 'Uusi keskustelu luotu.',
	'groups:topicsticky' => 'Sticky',
	'groups:topicisclosed' => 'Tämä aihe on suljettu.',
	'groups:topiccloseddesc' => 'Tämä keskustelu on suljettu eikä siihen voi enää lisätä kommentteja.',
	'grouptopic:error' => 'Keskustelua ei voitu luoda. Yritä uudelleen. Jos virhe toistuu, ota yhteyttä sivuston ylläpitäjään.',
	'groups:forumpost:edited' => "Viesti päivitetty.",
	'groups:forumpost:error' => "Viestin päivittämisess ilmeni ongelma.",

	'groups:privategroup' => 'Tämä ryhmä on suljettu. Anotaan jäsenyyttä.',
	'groups:notitle' => 'Ryhmällä pitää olla nimi',
	'groups:cantjoin' => 'Ryhmään liittyminen epäonnistui',
	'groups:cantleave' => 'Ryhmästä eroaminen epäonnistui',
	'groups:removeuser' => 'Poista ryhmästä',
	'groups:cantremove' => 'Käyttäjää ei voida poistaa ryhmästä',
	'groups:removed' => 'Käyttäjä %s poistettiin ryhmästä',
	'groups:addedtogroup' => 'Käyttäjä lisättiin ryhmään',
	'groups:joinrequestnotmade' => 'Ryhmän jäsenyyden anominen epäonnistui',
	'groups:joinrequestmade' => 'Lähetettiin pyyntö päästä ryhmän jäseneksi',
	'groups:joined' => 'Olet nyt ryhmän jäsen!',
	'groups:left' => 'Olet nyt eronnut ryhmästä',
	'groups:notowner' => 'Et ole ryhmän omistaja.',
	'groups:notmember' => 'Et ole ryhmän jäsen.',
	'groups:alreadymember' => 'Olet jo ryhmän jäsenenä!',
	'groups:userinvited' => 'Käyttäjä kutsuttu.',
	'groups:usernotinvited' => 'Käyttäjän kutsuminen epäonnistui.',
	'groups:useralreadyinvited' => 'Käyttäjä on jo kutsuttu',
	'groups:invite:subject' => "%s sinut on kutsuttu ryhmän %s jäseneksi!",
	'groups:updated' => "Viimeisin viesti käyttäjältä %s %s",
	'groups:started' => "Aloittaja %s",
	'groups:joinrequest:remove:check' => 'Haluatko varmasti poistaa tämän liittymispyynnön?',
	'groups:invite:remove:check' => 'Haluatko varmasti poistaa tämän kutsun?',
	'groups:invite:body' => "Hei %s,

%s on kutsunut sinut liittymään ryhmään '%s'. Klikkaa linkkiä nähdäksesi kutsun:

%s",

	'groups:welcome:subject' => "Tervetuloa ryhmään %s!",
	'groups:welcome:body' => "Hei %s!

Olet nyt ryhmän '%s' jäsen! Klikkaa linkkiä päästäksesi alkuun!

%s",

	'groups:request:subject' => "%s on anonut jäsenyyttä ryhmään %s",
	'groups:request:body' => "Hei %s,

%s on anonut jäsenyyttä ryhmään '%s'. Klikkaa tästä nähdäksesi hänen profiilinsa:

%s

tai tästä nähdäksesi ryhmän jäsenanomukset:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s loi ryhmän %s',
	'river:join:group:default' => '%s liittyi ryhmään %s',
	'river:create:object:groupforumtopic' => '%s lisäsi uuden keskusteluaiheen %s',
	'river:reply:object:groupforumtopic' => '%s vastasi keskusteluun %s',
	'river:reply:view' => 'näytä vastaukset',

	'groups:nowidgets' => 'Tälle ryhmälle ei ole määritetty vimpaimia.',


	'groups:widgets:members:title' => 'Ryhmän jäsenet',
	'groups:widgets:members:description' => 'Listaa ryhmän jäsenet.',
	'groups:widgets:members:label:displaynum' => 'Listaa ryhmän jäsenet.',
	'groups:widgets:members:label:pleaseedit' => 'Määrittele vimpaimelle asetukset.',

	'groups:widgets:entities:title' => "Kohdetta ryhmässä",
	'groups:widgets:entities:description' => "Listaa ryhmässä olevat kohteet",
	'groups:widgets:entities:label:displaynum' => 'Listaa ryhmässä olevat kohteet.',
	'groups:widgets:entities:label:pleaseedit' => 'Määrittele vimpaimelle asetukset.',

	'groups:forumtopic:edited' => 'Muokattiin aihetta.',

	'groups:allowhiddengroups' => 'Sallitaanko suljettujen (piilotettujen) ryhmien luominen?',
	'groups:whocancreate' => 'Kuka voi luoda uusia ryhmiä?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Ryhmä ja sen sisällöt poistettu',
	'group:notdeleted' => 'Ryhmää ei voitu poistaa',

	'group:notfound' => 'Ryhmää ei löytynyt',
	'grouppost:deleted' => 'Viesti poistettu',
	'grouppost:notdeleted' => 'Viestiä ei voity poistaa',
	'groupstopic:deleted' => 'Aihe poistettu',
	'groupstopic:notdeleted' => 'Aihetta ei voitu poistaa',
	'grouptopic:blank' => 'Ei aihetta',
	'grouptopic:notfound' => 'Aihetta ei löytynyt',
	'grouppost:nopost' => 'Tyhjä viesti',
	'groups:deletewarning' => "Haluatko varmasti poistaa tämän ryhmän? Tätä toimintoa ei voi perua!",

	'groups:invitekilled' => 'Kutsu poistettu.',
	'groups:joinrequestkilled' => 'Pyyntö poistettu.',
	'groups:error:addedtogroup' => "Käyttäjän %s lisääminen epäonnistui",
	'groups:add:alreadymember' => "%s on jo tämän ryhmän jäsen",

	/**
	 * ecml
	 */
	'groups:ecml:discussion' => 'Ryhmän keskustelut',
	'groups:ecml:groupprofile' => 'Ryhmät',
);

==> elgg-2.3.3.zip: elgg-2.3.3/mod/groups/languages/fi.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Ryhmät",
	'groups:owned' => "Ryhmät, jotka omistan",
	'groups:owned:user' => 'Käyttäjän %s omistamat ryhmät',
	'groups:yours' => "Omat ryhmäni",
	'groups:user' => "Käyttäjän %s ryhmät",
	'groups:all' => "Kaikki ryhmät",
	'groups:add' => "Luo uusi ryhmä",
	'groups:edit' => "Muokkaa ryhmää",
	'groups:delete' => 'Poista ryhmä',
	'groups:membershiprequests' => 'Hallinnoi liittymispyyntöjä',
	'groups:membershiprequests:pending' => 'Hallinnoi liittymispyyntöjä (%s)',
	'groups:invitations' => 'Ryhmäkutsut',
	'groups:invitations:pending' => 'Ryhmäkutsut (%s)',

	'groups:icon' => 'Ryhmän kuvake (jätä tyhjäksi, jos et halua vaihtaa)',
	'groups:name' => 'Ryhmän nimi',
	'groups:username' => 'Ryhmän lyhyt nimi (näytetään osoitteissa, käytä vain kirjaimia ja numeroita)',
	'groups:description' => 'Kuvaus',
	'groups:briefdescription' => 'Lyhyt kuvaus',
	'groups:interests' => 'Tagit',
	'groups:website' => 'Nettisivu',
	'groups:members' => 'Ryhmän jäsenet',
	'groups:my_status' => 'Oma jäsenyytesi',
	'groups:my_status:group_owner' => 'Olet ryhmän omistaja',
	'groups:my_status:group_member' => 'Olet ryhmän jäsen',
	'groups:subscribed' => 'Group notifications are on',
	'groups:unsubscribed' => 'Group notifications are off',

	'groups:members:title' => 'Jäsenet ryhmässä: %s',
	'groups:members:more' => "Näytä kaikki jäsenet",
	'groups:membership' => "Ryhmän jäsenyysasetukset",
	'groups:content_access_mode' => "Pääsy ryhmän sisältöihin",
	'groups:content_access_mode:warning' => "Varoitus: Asetuksen muuttaminen vaikuttaa vain uusiin sisältöihin.",
	'groups:content_access_mode:unrestricted' => "Rajoittamaton - Näkyvyys riippuu kunkin sisällön omasta näkyvyystasosta",
	'groups:content_access_mode:membersonly' => "Vain jäsenet - Ryhmän ulkopuoliset eivät pääse ollenkaan käsiksi sisältöihin",
	'groups:access' => "Pääsyoikeudet",
	'groups:owner' => "Omistaja",
	'groups:owner:warning' => "Varoitus: Jos muutat tätä, luovut ryhmän omistajuudesta.",
	'groups:widget:num_display' => 'Näytettävien ryhmien määrä',
	'groups:widget:membership' => 'Ryhmien jäsenyys',
	'groups:widgets:description' => 'Näytä profiilissasi ryhmät, joiden jäsenenä olet',

	'groups:widget:group_activity:title' => 'Ryhmän toiminta',
	'groups:widget:group_activity:description' => 'Näyttää valitsemasi ryhmän toiminta',
	'groups:widget:group_activity:edit:select' => 'Valitse',
	'groups:widget:group_activity:content:noactivity' => 'Ryhmässä ei ole vielä ollut toimintaa',
	'groups:widget:group_activity:content:noselect' => 'Valitse ryhmä vimpaimen asetuksista',

	'groups:noaccess' => 'Sinulla ei ole oikeuksia tämän ryhmän näkemiseen',
	'groups:ingroup' => 'ryhmässä',
	'groups:cantcreate' => 'Vain sivuston ylläpitäjät voivat luoda uusia ryhmiä.',
	'groups:cantedit' => 'Voit nyt muokata ryhmää',
	'groups:saved' => 'Ryhmä tallennettu',
	'groups:save_error' => 'Ryhmän tallentaminen epäonnistui',
	'groups:featured' => 'Valikoidut ryhmät',
	'groups:makeunfeatured' => 'Poista mainos',
	'groups:makefeatured' => 'Mainosta ryhmää',
	'groups:featuredon' => '%s on nyt mainostettu ryhmä.',
	'groups:unfeatured' => '%s on poistettu mainostettavista ryhmistä.',
	'groups:featured_error' => 'Virheellinen ryhmä.',
	'groups:nofeatured' => 'Ei valikoituja ryhmiä',
	'groups:joinrequest' => 'Ano jäsenyyttä',
	'groups:join' => 'Liity ryhmään',
	'groups:leave' => 'Eroa ryhmästä',
	'groups:invite' => 'Kutsu ystäviä',
	'groups:invite:title' => 'Kutsu ystäviä ryhmään',
	'groups:inviteto' => "Kutsu ystäviä ryhmään '%s'",
	'groups:nofriends' => "Kaikki ystäväsi on jo kutsuttu ryhmän jäseniksi.",
	'groups:nofriendsatall' => 'Sinulla ei vielä ole ystäviä, joita kutsua!',
	'groups:viagroups' => "lisäsi uuden viestin keskusteluun",
	'groups:group' => "Ryhmä",
	'groups:search:tags' => "tagi",
	'groups:search:title' => "Ryhmät, joissa tagi '%s'",
	'groups:search:none' => "Ryhmiä ei löytynyt",
	'groups:search_in_group' => "Etsi tästä ryhmästä",
	'groups:acl' => "Ryhmä: %s",

	'groups:activity' => "Ryhmän toiminta",
	'groups:enableactivity' => 'Ota käyttöön ryhmän toiminta',
	'groups:activity:none' => "Ryhmässä ei vielä ole ollut toimintaa",

	'groups:notfound' => "Ryhmää ei löytynyt",
	'groups:notfound:details' => "Pyydettyä ryhmää ei joko ole olemassa tai sinulla ei ole oikeuksia siihen",

	'groups:requests:none' => 'Ei odottavia jäsenyyspyyntöjä.',

	'groups:invitations:none' => 'Ei odottavia kutsuja.',

	'groups:count' => "ryhmää luotuna",
	'groups:open' => "avoin ryhmä",
	'groups:closed' => "suljettu ryhmä",
	'groups:member' => "jäsentä",
	'groups:searchtag' => "Etsi ryhmiä tagin perusteella",

	'groups:more' => 'Lisää ryhmiä',
	'groups:none' => 'Ei ryhmiä',

	/**
	 * Access
	 */
	'groups:access:private' => 'Suljettu - Jäsenet pitää kutsua',
	'groups:access:public' => 'Avoin - Kuka tahansa voi liittyä',
	'groups:access:group' => 'Vain ryhmän jäsenet',
	'groups:closedgroup' => "Tällä ryhmällä on suljettu jäsenyys.",
	'groups:closedgroup:request' => 'Klikkaa linkkiä "Ano jäsenyyttä" päästäksesi jäseneksi.',
	'groups:closedgroup:membersonly' => "Tällä ryhmällä on suljettu jäsenyys, ja vain jäsenet pääsevät käsiksi sen sisältöihin.",
	'groups:opengroup:membersonly' => "Vain jäsenillä on pääsy tämän ryhmän sisältöihin.",
	'groups:opengroup:membersonly:join' => 'Klikkaa "Liity ryhmään" päästäksesi ryhmän jäseneksi.',
	'groups:visibility' => 'Kuka voi nähdä tämän ryhmän?',

	/**
	 * Group tools
	 */
	'groups:lastupdated' => 'Viimeksi päivitetty %s käyttäjän %s toimesta',
	'groups:lastcomment' => 'Viimeksi kommentoitu %s käyttäjän %s toimesta',

	'admin:groups' => 'Ryhmät',

	'groups:privategroup' => 'Tämä ryhmä on suljettu. Anotaan jäsenyyttä.',
	'groups:notitle' => 'Ryhmällä pitää olla nimi',
	'groups:cantjoin' => 'Ryhmään liittyminen epäonnistui',
	'groups:cantleave' => 'Ryhmästä eroaminen epäonnistui',
	'groups:removeuser' => 'Poista ryhmästä',
	'groups:cantremove' => 'Käyttäjää ei voida poistaa ryhmästä',
	'groups:removed' => 'Käyttäjä %s poistettiin ryhmästä',
	'groups:addedtogroup' => 'Käyttäjä lisättiin ryhmään',
	'groups:joinrequestnotmade' => 'Ryhmän jäsenyyden anominen epäonnistui',
	'groups:joinrequestmade' => 'Lähetettiin pyyntö päästä ryhmän jäseneksi',
	'groups:joined' => 'Olet nyt ryhmän jäsen!',
	'groups:left' => 'Olet nyt eronnut ryhmästä',
	'groups:notowner' => 'Et ole ryhmän omistaja.',
	'groups:notmember' => 'Et ole ryhmän jäsen.',
	'groups:alreadymember' => 'Olet jo ryhmän jäsenenä!',
	'groups:userinvited' => 'Käyttäjä kutsuttu.',
	'groups:usernotinvited' => 'Käyttäjän kutsuminen epäonnistui.',
	'groups:useralreadyinvited' => 'Käyttäjä on jo kutsuttu',
	'groups:invite:subject' => "%s sinut on kutsuttu ryhmän %s jäseneksi!",
	'groups:started' => "Aloittaja %s",
	'groups:joinrequest:remove:check' => 'Haluatko varmasti poistaa tämän liittymispyynnön?',
	'groups:invite:remove:check' => 'Haluatko varmasti poistaa tämän kutsun?',
	'groups:invite:body' => "Hei %s,

%s on kutsunut sinut liittymään ryhmään '%s'. Klikkaa linkkiä nähdäksesi kutsun:

%s",

	'groups:welcome:subject' => "Tervetuloa ryhmään %s!",
	'groups:welcome:body' => "Hei %s!

Olet nyt ryhmän '%s' jäsen! Klikkaa linkkiä päästäksesi alkuun!

%s",

	'groups:request:subject' => "%s on anonut jäsenyyttä ryhmään %s",
	'groups:request:body' => "Hei %s,

%s on anonut jäsenyyttä ryhmään '%s'. Klikkaa tästä nähdäksesi hänen profiilinsa:

%s

tai tästä nähdäksesi ryhmän jäsenanomukset:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s loi ryhmän %s',
	'river:join:group:default' => '%s liittyi ryhmään %s',

	'groups:nowidgets' => 'Tälle ryhmälle ei ole määritetty vimpaimia.',


	'groups:widgets:members:title' => 'Ryhmän jäsenet',
	'groups:widgets:members:description' => 'Listaa ryhmän jäsenet.',
	'groups:widgets:members:label:displaynum' => 'Listaa ryhmän jäsenet.',
	'groups:widgets:members:label:pleaseedit' => 'Määrittele vimpaimelle asetukset.',

	'groups:widgets:entities:title' => "Kohdetta ryhmässä",
	'groups:widgets:entities:description' => "Listaa ryhmässä olevat kohteet",
	'groups:widgets:entities:label:displaynum' => 'Listaa ryhmässä olevat kohteet.',
	'groups:widgets:entities:label:pleaseedit' => 'Määrittele vimpaimelle asetukset.',

	'groups:allowhiddengroups' => 'Sallitaanko suljettujen (piilotettujen) ryhmien luominen?',
	'groups:whocancreate' => 'Kuka voi luoda uusia ryhmiä?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Ryhmä ja sen sisällöt poistettu',
	'group:notdeleted' => 'Ryhmää ei voitu poistaa',

	'group:notfound' => 'Ryhmää ei löytynyt',
	'groups:deletewarning' => "Haluatko varmasti poistaa tämän ryhmän? Tätä toimintoa ei voi perua!",

	'groups:invitekilled' => 'Kutsu poistettu.',
	'groups:joinrequestkilled' => 'Pyyntö poistettu.',
	'groups:error:addedtogroup' => "Käyttäjän %s lisääminen epäonnistui",
	'groups:add:alreadymember' => "%s on jo tämän ryhmän jäsen",

	/**
	 * ecml
	 */
	'groups:ecml:groupprofile' => 'Ryhmät',
);
